@@ -1,22 +1,22 @@
 // *****************************************************************************
 /*
  * Copyright (C) 2006-2012 Olivier Tilloy <olivier@tilloy.net>
- * Copyright (C) 2015-2021 Vincent Vande Vyvre <vincent.vandevyvre@oqapy.eu>
+ * Copyright (C) 2015-2022 Vincent Vande Vyvre <vincent.vandevyvre@oqapy.eu>
  *
  * This file is part of the pyexiv2 distribution.
  *
- * pyexiv2 is free software; you can redistribute it and/or
+ * py3exiv2 is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
  * of the License, or (at your option) any later version.
  *
- * pyexiv2 is distributed in the hope that it will be useful,
+ * py3exiv2 is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with pyexiv2; if not, write to the Free Software
+ * along with py3exiv2; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, 5th Floor, Boston, MA 02110-1301 USA.
  */
 /*
@@ -29,6 +29,12 @@
 #include "boost/python/stl_iterator.hpp"
 #include <fstream>
 
+#if __cplusplus >= 201103L
+template <typename T>
+using auto_ptr = std::unique_ptr<T>;
+#else
+using std::auto_ptr;
+#endif
 
 // Custom error codes for Exiv2 exceptions
 #define METADATA_NOT_READ 101
