@@ -1,7 +1,7 @@
 // *****************************************************************************
 /*
  * Copyright (C) 2006-2010 Olivier Tilloy <olivier@tilloy.net>
- * Copyright (C) 2015-2021 Vincent Vande Vyvre <vincent.vandevyvre@oqapy.eu>
+ * Copyright (C) 2015-2022 Vincent Vande Vyvre <vincent.vandevyvre@oqapy.eu>
  *
  * This file is part of the py3exiv2 distribution.
  *
@@ -33,6 +33,13 @@
 
 #include "boost/python.hpp"
 
+#if __cplusplus >= 201103L
+template <typename T>
+using auto_ptr = std::unique_ptr<T>;
+#else
+using std::auto_ptr;
+#endif
+
 namespace exiv2wrapper
 {
 
